
### 订单相关

#### 订单查询
```
/orders
GET
{
  'orderStatus':0,
  'timeBegin':2233222,
  'timeEnd':23232332,
  'userCode':'xxx',
  'campusName':'xxx',
  'campusCode':'xxx',
  'pageSize':10,
  'pageNum':0,
}
返回
{
    'code':200,
    'success': true,
    'message': null,
    'data':{
        'totalNum':200,
        'pageNum':0,
        'pageSize':10,
        'recs':[
          {
              'id':'xxx',
              'code':'xxxx',
              'uid':'xxx',
              'userCode':'xxx',
              'provinceCode':'xxx',
              'cityName':'xxx',
              'zoneName':'xxxx',
              'classroomName':'xxxx',
              'finalPrice':2332.12,
              'merchantPrice':2332.12,
              'status':0,
              'gmtCreated':1342342,
          }
          ...
        ]
    }

}

```

>请求参数

|name |type| null | desc |
|---- |:---|:---|:----:|
| orderStatus | string | no | 订单状态，取值{0,1,2}, 分别表示{未支付，已支付，已删除} |
| timeBegin | unix stamp | yes | 查询开始时间 |
| timeEnd | unix stamp | yes | 查询结束时间 |
| campusName | string | yes | 校区名 |
| campusCode | string | yes | 校区名 |
| userCode | string | yes | 校区名 |
| pageSize | int | no | 分布大小 |
| pageNum | int | no | 页码，从0开始 |

>返回参数

|name |type| null | desc |
|---- |:---|:---|:----:|
| totalNum | int | no | 返回总结果数 |
| id | string | no | 订单id |
| uid | string | no | 用户id |
| userCode | string | no | 学号 |
| code | string | no | recs中的code, 表示订单号 |
| finalPrice | float | no | 表示最终的成交价 |
| lingjiaoPrice | float | no | 表示领教给渠道的价格 |
| gmtCreated | unixStamp | no | 表示订单创建的时间 |

---

#### 创建订单
```
/order/
POST
{
  'uid':'xxxx',
  'priceAdjust':-200.01,
  'note':'xxx',
  'recs':[
    {
      'goodsId':'xxx',
      'quantity':2,
    },
    ...
    ]
}
返回
{
  'code':200,
  'success': true,
  'message': null,
  'data':{
      'id':'xxxx'
  }
}
```

>请求参数

|name |type| null | desc |
|---- |:---|:---|:----:|
| uid | string | no | 终端用户id |
| priceAdjust | float | no | 订单价格调整，正数表示加，负数表示减 |
| recs | jsonArray | no | 要购买的商品记录数组 |
| goodsId | string | no | 商品id |
| quantity | int | no | 购买的数量 |
| note | int | no | 订单备注 |

>返回参数

|name |type| null | desc |
|---- |:---|:---|:----:|
| id | string | no | 订单id |

---

#### 查询产品列表
```
/products
GET
{
  'code':'xxx',
  'name':'xxxx',
  'type':0,
  'merchantId':23,
  'pageSize':10,
  'pageNum':0,
}
返回
{
    "code": 200,
    "success": true,
    "message": null,
    "data": {
      'totalNum':300,
      'page':0,
      'pageSize':10
      'recs':[
        {
          'id':'xxx',
          'name':'xxx',
          'code':'xxx',
          'type':'xxx',
          'gmt_modified':1321232,
          'merchantId':'xxxx',
          'goods':[{
            'id':'xxx',
            'duration':2322,
            'chargeUnit':'xxx',
            'cpPrice':12.01,
            'merchantPrice':23.92,
            'terminalPrice':50.1,
            },
            ...
            ],
        }
        ...
      ],
    }
}
```

>请求参数

|name |type| null | desc |
|---- |:---|:---|:----:|
| code | string | yes | product的编号 |
| name | string | yes | item名称 |
| type | int | yes | item类型 |
| merchantId | int | yes | item类型 |

---

#### 获取特定产品详情
```
/product
GET
{
  'productId':'xxxx',
  'product_type':2,
}
返回
{
    "code": 200,
    "success": true,
    "message": null,
    "data": {
          'id':'xxx',
          'name':'xxx',
          'type':'xxx',
          'code':'xxx',
          'gmt_modified':1321232,
          'goods':[{
            'id':'xxx',
            'merchantId':'xxxx',
            'duration':2322,
            'chargeUnit':'xxx',
            'cpPrice':12.01,
            'merchantPrice':23.92,
            'terminalPrice':50.1,
            }],
    }
}
```

---

#### 创建课程包
```
/package
POST
{
  'code':'xxx',
  'name':'xxxx',
  'recs':[
    {
      'pid':'pid1xxx',
      'product_type':2,
      'cpPriceInPackage':101.23,
    },
    ...
  ],
}
返回
{
    "code": 200,
    "success": true,
    "message": null,
    "data": {
      'id':'xxxx',
    }
}
```

#### 修改课程包
```
/package/<packageId>
PUT
{
    /*参考/package/-POST请求参数*/
}
返回
{
    "code": 200,
    "success": true,
}
```
---

#### 创建商品
```
/goods
POST
{
  'pid':'xxx',
  'productType':1,
  'merchantId':'xxxx',
  'duration':'xxxx',
  'chargeUnit':'xxxx',
  'cpPrice':12.01,
  'merchantPrice':12.11,
  'terminalPrice':32.11,
}
返回
{
  "code": 200,
  "success": true,
  "message": null,
  'data':{
    'id':'xxxx',
  }
}
```
---

#### 修改商品
```
/goods/<goodsId>
PUT
{
  /*参考/goods-POST参数*/
}
返回
{
  "code": 200,
  "success": true,
}
```

---

#### 查询销售数据
```
/soldProduct
GET
{
  'uid':'xxx',
  'userCode':'xxx',
  'userName':'xxx',
  'campusId':'xxx',
  'campusCode':'xxx',
  'campusName':'xxx',
  'pkgId':'xxx',
  'pid':'xxx',
  'productCode':'xxx',
  'cpId':'xxx',
  'merchantId':'xxx',
  'pageNum':0,
  'pageSize':10,
}
返回
{
  "code": 200,
  "success": true,
  "message": null,
  "data": {
      'totalNum':300,
      'page':0,
      'pageSize':10
      'recs':[
        {
          'uid':'xxx',
          'userCode':'xxx',
          'userName':'xxx',
          'campusId':'xxx',
          'campusCode':'xxx',
          'campusName':'xxx',
          'orderId':'xxx',
          'goodsId':'xxx',
          'pkgId':'xxx',
          'pid':'xxx',
          'productType':'xxx',
          'productCode':'xxx',
          'productName':'xxx',
          'merchantId':'xxxx',
          'duration':2322,
          'cpId':'xxxx',
          'cpPrice':2,
          'merchantPrice':2,
          'terminalPrice':2,
          'chargeUnit':2,
          'quantity':2,
          'gmt_created':213423,
        }
        ...
      ],
    }
}
```

>请求参数(所有请求参数皆非必需)
